"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TripletexBase = void 0;
const date_fns_1 = require("date-fns");
const ts_invariant_1 = require("ts-invariant");
const typical_fetch_1 = require("typical-fetch");
const utils_1 = require("../utils");
const token_1 = require("./token/token");
class TripletexBase {
    constructor(config, sessionToken) {
        this.config = config;
        this.sessionToken = sessionToken;
        this.tokenClient = new token_1.TripletexToken(config);
    }
    authenticatedCall() {
        return (0, typical_fetch_1.buildCall)() //
            .args()
            .baseUrl(this.config.baseUrl ?? utils_1.defaultBaseUrl)
            .headers(({ sessionToken }) => {
            const basicAuth = Buffer.from([
                this.config.organizationId ?? '0',
                sessionToken,
            ].join(':')).toString('base64');
            return {
                'User-Agent': this.config.userAgent ?? 'bjerkio-tripletex/3',
                Authorization: `Basic ${basicAuth}`,
            };
        });
        // .mapError(errorParser);
    }
    unauthenticatedCall() {
        return (0, typical_fetch_1.buildCall)() //
            .baseUrl(this.config.baseUrl ?? utils_1.defaultBaseUrl)
            .headers(() => ({
            'User-Agent': this.config.userAgent ?? 'bjerkio-tripletex/3',
        }));
        // .mapError(errorParser);
    }
    async performRequest(call) {
        const sessionToken = await this.getToken();
        for (let n = 0; n <= 3; n++) {
            const res = await call(sessionToken);
            if (res.success) {
                return res;
            }
            const { error } = res;
            if (error instanceof typical_fetch_1.TypicalHttpError && error.status === 429) {
                const resetHeader = error.res.headers?.get('X-Rate-Limit-Reset');
                const secondsToRetry = resetHeader ? Number(resetHeader) : 2;
                const millis = secondsToRetry * 1000 + 100;
                await new Promise(resolve => setTimeout(resolve, millis));
            }
            else {
                return res;
            }
        }
        throw new Error('Not able to perform request');
    }
    async getToken() {
        if (this.sessionToken) {
            return this.sessionToken;
        }
        const expirationDate = this.config.expirationDate ?? (0, date_fns_1.addDays)(new Date(), 2);
        (0, ts_invariant_1.invariant)(this.config.employeeToken, 'expected employeeToken in config');
        (0, ts_invariant_1.invariant)(this.config.consumerToken, 'expected consumerToken in config');
        const tokenRequest = await this.tokenClient.createSessionToken({
            employeeToken: this.config.employeeToken,
            consumerToken: this.config.consumerToken,
            expirationDate,
        });
        if (!tokenRequest.success) {
            throw new Error('Not able to retrieve session token');
        }
        this.sessionToken = tokenRequest.body.value.token;
        return this.sessionToken;
    }
}
exports.TripletexBase = TripletexBase;
