"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nock_1 = __importDefault(require("nock"));
const ts_invariant_1 = require("ts-invariant");
const utils_1 = require("../../../utils");
const event_1 = require("../event");
const baseUrl = process.env.BASE_URL || 'https://api.tripletex.io/';
const sessionToken = process.env.SESSION_TOKEN || 'a-session-token';
describe('activity class', () => {
    let client;
    beforeEach(() => {
        client = new event_1.TripletexEvent({ baseUrl }, sessionToken);
    });
    it('should create a subscription', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .post('/v2/event/subscription', {
            event: 'invoice.charged',
            targetUrl: 'http://example.com',
        })
            .reply(201, {
            value: {
                id: 48620,
                version: 0,
                url: 'api.tripletex.io/v2/event/subscription/48620',
                event: 'invoice.charged',
                targetUrl: 'http://example.com',
                fields: null,
                status: 'ACTIVE',
                authHeaderName: null,
            },
        });
        const subscription = await client.createSubscription({
            event: 'invoice.charged',
            targetUrl: 'http://example.com',
        });
        (0, utils_1.parseRuntypeValidationError)(subscription.error);
        (0, ts_invariant_1.invariant)(subscription.success);
        expect(subscription.body.value).toMatchSnapshot();
    });
    it('should get a subscription', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .get('/v2/event/subscription/48620')
            .reply(200, {
            value: {
                id: 48620,
                version: 0,
                url: 'api.tripletex.io/v2/event/subscription/48620',
                event: 'invoice.charged',
                targetUrl: 'http://example.com',
                fields: null,
                status: 'ACTIVE',
                authHeaderName: null,
            },
        });
        const subscription = await client.getSubscription(48620);
        (0, utils_1.parseRuntypeValidationError)(subscription.error);
        (0, ts_invariant_1.invariant)(subscription.success);
        expect(subscription.body.value).toMatchSnapshot();
    });
    it('should delete a subscription', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .delete('/v2/event/subscription/48619')
            .reply(204, '');
        const subscription = await client.deleteSubscription(48619);
        (0, utils_1.parseRuntypeValidationError)(subscription.error);
        expect(subscription.success).toBeTruthy();
    });
    it('should list subscriptions', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .get('/v2/event/subscription')
            .reply(200, {
            fullResultSize: 1,
            from: 0,
            count: 1,
            versionDigest: null,
            values: [
                {
                    id: 48620,
                    version: 0,
                    url: 'api.tripletex.io/v2/event/subscription/48620',
                    event: 'invoice.charged',
                    targetUrl: 'http://example.com',
                    fields: null,
                    status: 'ACTIVE',
                    authHeaderName: null,
                },
            ],
        });
        const subscription = await client.listSubscriptions();
        (0, utils_1.parseRuntypeValidationError)(subscription.error);
        (0, ts_invariant_1.invariant)(subscription.success);
        expect(subscription.body.values).toMatchSnapshot();
    });
    it('should create a subscription with fields', async () => {
        (0, nock_1.default)('https://api.tripletex.io:443', { encodedQueryParams: true })
            .post('/v2/event/subscription', {
            event: 'project.create',
            targetUrl: 'http://example.com',
            fields: 'id,name,number,isClosed',
        })
            .reply(201, {
            value: {
                id: 48638,
                version: 0,
                url: 'api.tripletex.io/v2/event/subscription/48638',
                event: 'project.create',
                targetUrl: 'http://example.com',
                fields: 'id,name,number,isClosed',
                status: 'ACTIVE',
                authHeaderName: null,
            },
        });
        const subscription = await client.createSubscription({
            event: 'project.create',
            targetUrl: 'http://example.com',
            fields: ['id', 'name', 'number', 'isClosed'],
        });
        (0, utils_1.parseRuntypeValidationError)(subscription.error);
        (0, ts_invariant_1.invariant)(subscription.success);
        expect(subscription.body.value).toMatchSnapshot();
    });
});
