"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const date_fns_1 = require("date-fns");
const nock_1 = __importDefault(require("nock"));
const ts_invariant_1 = require("ts-invariant");
const utils_1 = require("../../../utils");
const token_1 = require("../token");
const baseUrl = process.env.BASE_URL || 'https://api.tripletex.io/';
describe('token class', () => {
    let tokenClass;
    beforeEach(() => {
        tokenClass = new token_1.TripletexToken({ baseUrl });
    });
    it('should create session token', async () => {
        const expirationDate = (0, date_fns_1.addDays)(new Date(), 2);
        (0, nock_1.default)(baseUrl, { encodedQueryParams: true })
            .put('/v2/token/session/:create')
            .query({
            employeeToken: String(process.env.EMPLOYEE_TOKEN),
            consumerToken: String(process.env.CONSUMER_TOKEN),
            expirationDate: (0, utils_1.formatDate)(expirationDate),
        })
            .reply(200, {
            value: {
                id: 19015016,
                version: 1,
                url: 'api.tripletex.io/v2/token/session/19015016',
                consumerToken: {
                    id: 1754,
                    url: 'api.tripletex.io/v2/token/consumer/1754',
                },
                employeeToken: {
                    id: 2913,
                    url: 'api.tripletex.io/v2/token/employee/2913',
                },
                expirationDate: '2022-04-12',
                token: 'eyJ0b2tlbklkIjoxOTAxNTAxNiwidG9rZW4iOiJ0ZXN0LWIzMjU0NTg5LTU1OTctNDY0Mi04MmU5LTUyNDkyOWZlZGViNSJ9',
                encryptionKey: null,
            },
        });
        const token = await tokenClass.createSessionToken({
            employeeToken: String(process.env.EMPLOYEE_TOKEN),
            consumerToken: String(process.env.CONSUMER_TOKEN),
            expirationDate,
        });
        (0, ts_invariant_1.invariant)(token.success);
        expect(token.body.value.token).toEqual('eyJ0b2tlbklkIjoxOTAxNTAxNiwidG9rZW4iOiJ0ZXN0LWIzMjU0NTg5LTU1OTctNDY0Mi04MmU5LTUyNDkyOWZlZGViNSJ9');
    });
});
